@@ -2,13 +2,11 @@
 
 __all__ = [
     'format_key',
-    'raise_when_wrong_type',
+    'wrap_exception',
 ]
 
 import redis
 
-from functools import wraps
-
 def format_key(key, name, value):
     """ 
     提供对 Key 对象的格式化支持。
@@ -16,11 +14,11 @@ def format_key(key, name, value):
     type = key.__class__.__name__.title()
     return "{0} Key '{1}': {2}".format(type, name, value)
 
-def raise_when_wrong_type(func):
+def wrap_exception(func):
     """
-    将 redis-py 抛出的 ResponseError 转换为 TypeError 
+    redis-py 在对数据结构执行不属于它的操作时抛出 ResponseError
+    这里将 ResponseError 转换为 TypeError
     """
-    @wraps(func)
     def wrapper(*args, **kwargs):
         try:
             return func(*args, **kwargs)
